window.Gleam.initSearch([{"doc":"trie_again","title":"trie_again","content":"# trie_again\n\n[![Package Version](https://img.shields.io/hexpm/v/trie_again)](https://hex.pm/packages/trie_again)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/trie_again/)\n![CI](https://github.com/giacomocavalieri/trie_again/workflows/CI/badge.svg?branch=main)\n\nTries in Gleam 🌳\n\n&gt; ⚙️ This package supports the Erlang and Javascript targets!\n\n## Installation\n\nTo add this package to your Gleam project:\n\n```sh\ngleam add trie_again\n```\n\n## Usage\n\nImport the `trie` module and write some code! You can find many examples of how the different functions work in the [project documentation](https://hexdocs.pm/trie_again/).\n\n```gleam\nimport trie\n\ntrie.new()\n|&gt; trie.insert(at: [&quot;c&quot;, &quot;a&quot;, &quot;r&quot;], value: 1)\n|&gt; trie.insert(at: [&quot;c&quot;, &quot;a&quot;, &quot;t&quot;], value: 10)\n|&gt; trie.get(at: [&quot;c&quot;, &quot;a&quot;, &quot;t&quot;])\n// -&gt; Ok(10)\n```\n\n## Contributing\n\nIf you think there&#39;s any way to improve this package, or if you spot a bug don&#39;t be afraid to open PRs, issues or requests of any kind! Any contribution is welcome 💜\n","url":"index.html"},{"doc":"trie","title":"Trie","content":"pub opaque type Trie(k, v)\n A `Trie(k, v)` is a data structure that allows to store values of type `v` indexed by lists\n of values of type `k`.\n \n\nSynonyms:\ntrie.Trie\ntrie Trie","url":"trie.html#Trie"},{"doc":"trie","title":"delete","content":"pub fn delete(from trie: Trie(a, b), at path: List(a)) -&gt; Trie(\n  a,\n  b,\n)\n Deletes from a trie the value associated with a given path.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; delete(at: [1, 2])\n &gt; |&gt; to_list\n [#([1], &quot;b&quot;)]\n \n \n \n &gt; new()\n &gt; |&gt; delete(at: [1, 2])\n &gt; |&gt; to_list\n []\n \n \nSynonyms:\ntrie.delete\ntrie delete","url":"trie.html#delete"},{"doc":"trie","title":"fold","content":"pub fn fold(over trie: Trie(a, b), from initial: c, with fun: fn(\n    c,\n    List(a),\n    b,\n  ) -&gt; c) -&gt; c\n Combines all the trie&#39;s values into a single one by calling a given function on each one.\n \n The function takes as input the accumulator, the path of a value and the corresponding value.\n \n ## Examples\n \n \n &gt; [#([1, 2], 10), #([1], 1)]\n &gt; |&gt; from_list\n &gt; |&gt; fold(from: 0, with: fn(sum, _, value) { sum + value })\n 11\n \n \nSynonyms:\ntrie.fold\ntrie fold","url":"trie.html#fold"},{"doc":"trie","title":"from_list","content":"pub fn from_list(list: List(#(List(a), b))) -&gt; Trie(a, b)\n Creates a new trie from a list of path-value pairs.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; to_list\n [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n \n\nSynonyms:\ntrie.from_list\ntrie from_list","url":"trie.html#from_list"},{"doc":"trie","title":"get","content":"pub fn get(from: Trie(a, b), at path: List(a)) -&gt; Result(b, Nil)\n Fetches a value from a trie for a given path.\n If a value is present at the given path it returns it wrapped in an `Ok`,\n otherwise it returns `Error(Nil)`.\n \n ## Examples\n \n \n &gt; new()\n &gt; |&gt; get(at: [1, 2])\n Result(Nil)\n \n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; get(at: [1, 2])\n Ok(&quot;a&quot;)\n \n \nSynonyms:\ntrie.get\ntrie get","url":"trie.html#get"},{"doc":"trie","title":"has_path","content":"pub fn has_path(trie: Trie(a, b), path: List(a)) -&gt; Bool\n Determines wether a trie contains a value associated with the given path.\n \n ## Examples\n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; has_path([1, 2])\n True\n \n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; has_path([1])\n False\n \n \nSynonyms:\ntrie.has_path\ntrie has_path","url":"trie.html#has_path"},{"doc":"trie","title":"insert","content":"pub fn insert(into trie: Trie(a, b), at path: List(a), value value: b) -&gt; Trie(\n  a,\n  b,\n)\n Inserts a value in a trie at a given path. If there already is a value\n at the given path it is replaced by the new one.\n \n ## Examples\n \n \n &gt; new()\n &gt; |&gt; insert(at: [1, 2], value: &quot;a&quot;)\n &gt; |&gt; insert(at: [1], value: &quot;b&quot;)\n &gt; |&gt; to_list\n [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n \n \n \n &gt; new()\n &gt; |&gt; insert(at: [1, 2], value: &quot;a&quot;)\n &gt; |&gt; insert(at: [1, 2], value: &quot;b&quot;)\n &gt; |&gt; to_list\n [#([1, 2], &quot;b&quot;)]\n \n \nSynonyms:\ntrie.insert\ntrie insert","url":"trie.html#insert"},{"doc":"trie","title":"is_empty","content":"pub fn is_empty(trie: Trie(a, b)) -&gt; Bool\n Determines wether or not the trie is empty.\n \n ## Examples\n \n \n &gt; new()\n &gt; |&gt; is_empty\n True\n \n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; is_empty\n False\n \n \nSynonyms:\ntrie.is_empty\ntrie is_empty","url":"trie.html#is_empty"},{"doc":"trie","title":"map","content":"pub fn map(over trie: Trie(a, b), with fun: fn(b) -&gt; c) -&gt; Trie(\n  a,\n  c,\n)\n Updates all the values in a given trie by calling a function on each value.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; map(fn(s) { s &lt;&gt; &quot;!&quot; })\n &gt; |&gt; to_list\n [#([1, 2], &quot;a!&quot;), #([1], &quot;b!&quot;)]\n \n \nSynonyms:\ntrie.map\ntrie map","url":"trie.html#map"},{"doc":"trie","title":"new","content":"pub fn new() -&gt; Trie(a, b)\n Creates a new empty trie.\n \n ## Examples\n \n \n &gt; new()\n &gt; |&gt; to_list\n []\n \n \nSynonyms:\ntrie.new\ntrie new","url":"trie.html#new"},{"doc":"trie","title":"paths","content":"pub fn paths(trie: Trie(a, b)) -&gt; List(List(a))\n Gets a list of all the valid paths in the trie. That is all the paths associated with a value.\n \n Tries are not ordered so the paths are not returned in any specific order.\n Do not write code that relies on the order paths are returned by this function\n as it may change in later versions of the library.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; paths\n [[1, 2], [1]]\n \n \n \n &gt; new()\n &gt; |&gt; paths\n []\n \nSynonyms:\ntrie.paths\ntrie paths","url":"trie.html#paths"},{"doc":"trie","title":"singleton","content":"pub fn singleton(path: List(a), value: b) -&gt; Trie(a, b)\n Creates a new trie with a single value associated to the given path.\n \n ## Examples\n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; to_list\n [#([1, 2], &quot;a&quot;)]\n \n \nSynonyms:\ntrie.singleton\ntrie singleton","url":"trie.html#singleton"},{"doc":"trie","title":"size","content":"pub fn size(trie: Trie(a, b)) -&gt; Int\n Gets the number of elements in the trie.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; size\n 2\n \n \nSynonyms:\ntrie.size\ntrie size","url":"trie.html#size"},{"doc":"trie","title":"to_list","content":"pub fn to_list(trie: Trie(a, b)) -&gt; List(#(List(a), b))\n Turns a trie into a list of path-value pairs.\n \n ## Examples\n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; to_list\n [#([1, 2], &quot;a&quot;)]\n \n \n \n &gt; new()\n &gt; |&gt; to_list\n []\n \n\nSynonyms:\ntrie.to_list\ntrie to_list","url":"trie.html#to_list"},{"doc":"trie","title":"update","content":"pub fn update(trie: Trie(a, b), at path: List(a), with fun: fn(\n    Option(b),\n  ) -&gt; Option(b)) -&gt; Trie(a, b)\n Updates the value associated with a path applying it the given function.\n If there is no value associated with the given path the function is passed `None`.\n \n If the function returns `None` any value associated with the path is deleted from the trie.\n If the function returns `Some(value)` then the new value is associated to the given path.\n \n ## Examples\n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; update(at: [1, 2], with: fn(n) { n |&gt; option.map(fn(_) { &quot;b&quot; }) })\n &gt; |&gt; to_list\n [#([1, 2], &quot;b&quot;)] \n \n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; update(at: [1, 2], with: fn(_) { None })\n &gt; |&gt; to_list\n []\n \n \n \n &gt; singleton([1, 2], &quot;a&quot;)\n &gt; |&gt; update(at: [1], with: fn(_) { Some(&quot;b&quot;) })\n &gt; |&gt; to_list\n [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n \n \nSynonyms:\ntrie.update\ntrie update","url":"trie.html#update"},{"doc":"trie","title":"values","content":"pub fn values(trie: Trie(a, b)) -&gt; List(b)\n Gets a list of all the values in a given trie.\n \n Tries are not ordered so the values are not returned in any specific order.\n Do not write code that relies on the order values are returned by this function\n as it may change in later versions of the library.\n \n ## Examples\n \n \n &gt; [#([1, 2], &quot;a&quot;), #([1], &quot;b&quot;)]\n &gt; |&gt; from_list\n &gt; |&gt; values\n [&quot;a&quot;, &quot;b&quot;]\n \n \n \n &gt; new()\n &gt; |&gt; values\n []\n \n \nSynonyms:\ntrie.values\ntrie values","url":"trie.html#values"},{"doc":"trie","title":"trie","content":"","url":"trie.html"}]);